About Us
========

TrackC was originally written by Zan Yuan, and has been developed with the help 
of many others. Thanks to everyone who has improved TrackC by contributing code, 
bug reports (and fixes), documentation, and input on design, features, and the future of TrackC.

Contributors
------------

If you are a NetworkX contributor, please feel free to
open an `issue <https://github.com/seqyuan/trackc/issues/new>`_ or
submit a `pull request <https://github.com/seqyuan/trackc/compare/>`_
to add your name to the bottom of the list.

- Zan Yuan, GitHub: `seqyuan <https://github.com/seqyuan>`_
- Jiaying Yao
- Xinyu Tong
